[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAMN](https://git-scm.com/docs/git/sv#_namn)
    * [SYNOPSIS](https://git-scm.com/docs/git/sv#_synopsis)
    * [BESKRIVNING](https://git-scm.com/docs/git/sv#_beskrivning)
    * [ALTERNATIV](https://git-scm.com/docs/git/sv#_alternativ)
    * [GIT-KOMMANDON](https://git-scm.com/docs/git/sv#_git_kommandon)
    * [Högnivåkommandon (porslin)](https://git-scm.com/docs/git/sv#_h%c3%b6gniv%c3%a5kommandon_porslin)
    * [Lågnivåkommandon (rörmokeri)](https://git-scm.com/docs/git/sv#_l%c3%a5gniv%c3%a5kommandon_r%c3%b6rmokeri)
    * [Guider](https://git-scm.com/docs/git/sv#_guider)
    * [Gränssnitt för förvar, kommandon och filer](https://git-scm.com/docs/git/sv#_gr%c3%a4nssnitt_f%c3%b6r_f%c3%b6rvar_kommandon_och_filer)
    * [Filformat, protokoll och andra utvecklargränssnitt](https://git-scm.com/docs/git/sv#_filformat_protokoll_och_andra_utvecklargr%c3%a4nssnitt)
    * [Konfigurationsmekanism](https://git-scm.com/docs/git/sv#_konfigurationsmekanism)
    * [Identifierare Terminologi](https://git-scm.com/docs/git/sv#_identifierare_terminologi)
    * [Symboliska identifierare](https://git-scm.com/docs/git/sv#_symboliska_identifierare)
    * [Fil-/katalogstruktur](https://git-scm.com/docs/git/sv#_fil_katalogstruktur)
    * [Terminologi](https://git-scm.com/docs/git/sv#_terminologi)
    * [Miljövariabler](https://git-scm.com/docs/git/sv#_milj%c3%b6variabler)
    * [Discussion](https://git-scm.com/docs/git/sv#_discussion)
    * [SÄKERHET](https://git-scm.com/docs/git/sv#_s%c3%a4kerhet)
    * [YTTERLIGARE DOKUMENTATION](https://git-scm.com/docs/git/sv#_ytterligare_dokumentation)
    * [Författare](https://git-scm.com/docs/git/sv#_f%c3%b6rfattare)
    * [Rapportera buggar](https://git-scm.com/docs/git/sv#_rapportera_buggar)
    * [SE ÄVEN](https://git-scm.com/docs/git/sv#_se_%c3%a4ven)
    * [GIT](https://git-scm.com/docs/git/sv#_git)


[ Svenska ▾](https://git-scm.com/docs/git/sv)
Localized versions of **git** manual
  1. [English ](https://git-scm.com/docs/git)
  2. [Deutsch ](https://git-scm.com/docs/git/de)
  3. [Español ](https://git-scm.com/docs/git/es)
  4. [Français ](https://git-scm.com/docs/git/fr)
  5. [Português (Brasil) ](https://git-scm.com/docs/git/pt_BR)
  6. [Svenska ](https://git-scm.com/docs/git/sv)
  7. [українська мова ](https://git-scm.com/docs/git/uk)
  8. [简体中文 ](https://git-scm.com/docs/git/zh_HANS-CN)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/git/sv)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git/sv)
  * [ config ](https://git-scm.com/docs/git-config/sv)
  * [ help ](https://git-scm.com/docs/git-help/sv)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport/sv)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init/sv)
  * [ clone ](https://git-scm.com/docs/git-clone/sv)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add/sv)
  * [ status ](https://git-scm.com/docs/git-status/sv)
  * [ diff ](https://git-scm.com/docs/git-diff/sv)
  * [ commit ](https://git-scm.com/docs/git-commit/sv)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset/sv)
  * [ rm ](https://git-scm.com/docs/git-rm/sv)
  * [ mv ](https://git-scm.com/docs/git-mv/sv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch/sv)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge/sv)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool/sv)
  * [ log ](https://git-scm.com/docs/git-log/sv)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch/sv)
  * [ pull ](https://git-scm.com/docs/git-pull/sv)
  * [ push ](https://git-scm.com/docs/git-push/sv)
  * [ remote ](https://git-scm.com/docs/git-remote/sv)
  * [ submodule ](https://git-scm.com/docs/git-submodule/sv)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show/sv)
  * [ log ](https://git-scm.com/docs/git-log/sv)
  * [ diff ](https://git-scm.com/docs/git-diff/sv)
  * [ difftool ](https://git-scm.com/docs/git-difftool/sv)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog/sv)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply/sv)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff/sv)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert/sv)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect/sv)
  * [ blame ](https://git-scm.com/docs/git-blame/sv)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am/sv)
  * [ apply ](https://git-scm.com/docs/git-apply/sv)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info/sv)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary/sv)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore/sv)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean/sv)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck/sv)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive/sv)
  * [ bundle ](https://git-scm.com/docs/git-bundle/sv)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file/sv)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore/sv)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index/sv)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree/sv)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects/sv)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index/sv)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object/sv)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base/sv)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref/sv)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref/sv)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack/sv)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree/sv)


[ Latest version ▾ ](https://git-scm.com/docs/git/sv) git last updated in 2.53.0
Changes in the **git** manual
  1. [2.53.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2026-02-02_ ](https://git-scm.com/docs/git/2.53.0)
  2. [2.52.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-11-17_ ](https://git-scm.com/docs/git/2.52.0)
  3. 2.51.2 no changes
  4. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/git/2.51.1)
  5. 2.50.1 → 2.51.0 no changes
  6. [2.50.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-06-16_ ](https://git-scm.com/docs/git/2.50.0)
  7. 2.49.1 no changes
  8. [2.49.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-03-14_ ](https://git-scm.com/docs/git/2.49.0)
  9. 2.48.1 → 2.48.2 no changes
  10. [2.48.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-01-10_ ](https://git-scm.com/docs/git/2.48.0)
  11. 2.47.1 → 2.47.3 no changes
  12. [2.47.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-10-06_ ](https://git-scm.com/docs/git/2.47.0)
  13. 2.46.1 → 2.46.4 no changes
  14. [2.46.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-07-29_ ](https://git-scm.com/docs/git/2.46.0)
  15. 2.45.2 → 2.45.4 no changes
  16. [2.45.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.1)
  17. [2.45.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-29_ ](https://git-scm.com/docs/git/2.45.0)
  18. 2.44.2 → 2.44.4 no changes
  19. [2.44.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.44.1)
  20. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/git/2.44.0)
  21. 2.43.5 → 2.43.7 no changes
  22. [2.43.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.43.4)
  23. 2.43.2 → 2.43.3 no changes
  24. [2.43.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-09_ ](https://git-scm.com/docs/git/2.43.1)
  25. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/git/2.43.0)
  26. 2.42.3 → 2.42.4 no changes
  27. [2.42.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.42.2)
  28. [2.42.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-02_ ](https://git-scm.com/docs/git/2.42.1)
  29. [2.42.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-08-21_ ](https://git-scm.com/docs/git/2.42.0)
  30. 2.41.2 → 2.41.3 no changes
  31. [2.41.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.41.1)
  32. [2.41.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-06-01_ ](https://git-scm.com/docs/git/2.41.0)
  33. 2.40.3 → 2.40.4 no changes
  34. [2.40.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.40.2)
  35. 2.40.1 no changes
  36. 2.40.0 no changes
  37. 2.39.5 no changes
  38. [2.39.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-04-19_ ](https://git-scm.com/docs/git/2.39.4)
  39. 2.39.1 → 2.39.3 no changes
  40. [2.39.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-12_ ](https://git-scm.com/docs/git/2.39.0)
  41. 2.38.3 → 2.38.5 no changes
  42. [2.38.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-12-11_ ](https://git-scm.com/docs/git/2.38.2)
  43. 2.38.1 no changes
  44. [2.38.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-10-02_ ](https://git-scm.com/docs/git/2.38.0)
  45. 2.37.3 → 2.37.7 no changes
  46. [2.37.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-08-11_ ](https://git-scm.com/docs/git/2.37.2)
  47. 2.37.1 no changes
  48. [2.37.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-06-27_ ](https://git-scm.com/docs/git/2.37.0)
  49. 2.36.1 → 2.36.6 no changes
  50. [2.36.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-04-18_ ](https://git-scm.com/docs/git/2.36.0)
  51. 2.35.1 → 2.35.8 no changes
  52. [2.35.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-01-24_ ](https://git-scm.com/docs/git/2.35.0)
  53. 2.34.1 → 2.34.8 no changes
  54. [2.34.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-11-15_ ](https://git-scm.com/docs/git/2.34.0)
  55. 2.33.3 → 2.33.8 no changes
  56. [2.33.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2022-03-23_ ](https://git-scm.com/docs/git/2.33.2)
  57. [2.33.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-10-12_ ](https://git-scm.com/docs/git/2.33.1)
  58. 2.32.1 → 2.33.0 no changes
  59. [2.32.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-06-06_ ](https://git-scm.com/docs/git/2.32.0)
  60. 2.31.1 → 2.31.8 no changes
  61. [2.31.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2021-03-15_ ](https://git-scm.com/docs/git/2.31.0)
  62. 2.30.1 → 2.30.9 no changes
  63. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/git/2.30.0)
  64. 2.29.1 → 2.29.3 no changes
  65. [2.29.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-10-19_ ](https://git-scm.com/docs/git/2.29.0)
  66. 2.28.1 no changes
  67. [2.28.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-07-27_ ](https://git-scm.com/docs/git/2.28.0)
  68. 2.27.1 no changes
  69. [2.27.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-06-01_ ](https://git-scm.com/docs/git/2.27.0)
  70. 2.26.1 → 2.26.3 no changes
  71. [2.26.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-03-22_ ](https://git-scm.com/docs/git/2.26.0)
  72. 2.25.2 → 2.25.5 no changes
  73. [2.25.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-02-17_ ](https://git-scm.com/docs/git/2.25.1)
  74. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/git/2.25.0)
  75. 2.23.1 → 2.24.4 no changes
  76. [2.23.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-16_ ](https://git-scm.com/docs/git/2.23.0)
  77. 2.22.2 → 2.22.5 no changes
  78. [2.22.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-08-11_ ](https://git-scm.com/docs/git/2.22.1)
  79. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/git/2.22.0)
  80. 2.20.1 → 2.21.4 no changes
  81. [2.20.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-12-09_ ](https://git-scm.com/docs/git/2.20.0)
  82. 2.19.3 → 2.19.6 no changes
  83. [2.19.2 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-11-21_ ](https://git-scm.com/docs/git/2.19.2)
  84. 2.19.1 no changes
  85. [2.19.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-09-10_ ](https://git-scm.com/docs/git/2.19.0)
  86. 2.18.1 → 2.18.5 no changes
  87. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/git/2.18.0)
  88. 2.17.1 → 2.17.6 no changes
  89. [2.17.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-04-02_ ](https://git-scm.com/docs/git/2.17.0)
  90. [2.16.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.16.6)
  91. [2.15.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.15.4)
  92. [2.14.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-12-06_ ](https://git-scm.com/docs/git/2.14.6)
  93. 2.13.7 no changes
  94. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.12.5)
  95. [2.11.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.11.4)
  96. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/git/2.10.5)
  97. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.9.5)
  98. [2.8.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.8.6)
  99. [2.7.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/git/2.7.6)
  100. [2.6.7 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.6.7)
  101. [2.5.6 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.5.6)
  102. [2.4.12 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-05-05_ ](https://git-scm.com/docs/git/2.4.12)
  103. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/git/2.3.10)
  104. [2.2.3 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-04_ ](https://git-scm.com/docs/git/2.2.3)
  105. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.1.4)
  106. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/git/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/git/sv#_namn)NAMN
git - den dumma innehållsspåraren
##  [](https://git-scm.com/docs/git/sv#_synopsis)SYNOPSIS
```
_git_ [-v | --version] [-h |--help] [-C <sökväg>] [-c <namn>=<värde>]
           [--exec-path[=<sökväg>]] [--html-path] [--man-path] [--info-path]
           [-p | --paginate | -P | --no-pager] [--no-replace-objects] [--no-lazy-fetch]
           [--no-optional-locks] [--no-advice] [--bare] [--git-dir=<sökväg>]
           [--work-tree=<sökväg>] [--namespace=<namn>] [--config-env=<namn>=<miljövar>]
           <kommando> [<flaggor>]
```

##  [](https://git-scm.com/docs/git/sv#_beskrivning)BESKRIVNING
Git är ett snabbt, skalbart, distribuerat revisionskontrollsystem med en ovanligt rik kommandouppsättning som ger både övergripande operationer och fullständig åtkomst till interna funktioner.
See [gittutorial[7]](https://git-scm.com/docs/gittutorial/sv) to get started, then see [giteveryday[7]](https://git-scm.com/docs/giteveryday/sv) for a useful minimum set of commands. The [Git User’s Manual](https://git-scm.com/docs/user-manual/sv) has a more in-depth introduction.
När du bemästrar de grundläggande koncepten kan du återvända till den här sidan för att lära dig vilka kommandon Git erbjuder. Du kan lära dig mer om enskilda Git-kommandon med "git help command". Manualsidan för [gitcli[7]](https://git-scm.com/docs/gitcli/sv) ger dig en översikt över kommandoradssyntaxen.
En formaterad och hyperlänkad kopia av den senaste Git-dokumentationen kan ses på <https://git.github.io/htmldocs/git.html> eller <https://git-scm.com/docs>.
##  [](https://git-scm.com/docs/git/sv#_alternativ)ALTERNATIV

[](https://git-scm.com/docs/git/sv#git--v)-v


[](https://git-scm.com/docs/git/sv#git---version)--version

Skriver ut Git-svitversionen som _git_ -programmet kom från.
Det här alternativet konverteras internt till `git` `version` ... och accepterar samma alternativ som kommandot [git-version[1]](https://git-scm.com/docs/git-version/sv). Om `--help` också anges har det företräde framför `--version`.

[](https://git-scm.com/docs/git/sv#git--h)-h


[](https://git-scm.com/docs/git/sv#git---help)--help

Skriver ut synopsis och en lista över de vanligaste kommandona. Om alternativet `--all` eller `-a` anges skrivs alla tillgängliga kommandon ut. Om ett Git-kommando namnges kommer det här alternativet att visa manualsidan för det kommandot.
Andra alternativ finns tillgängliga för att kontrollera hur manualsidan visas. Se [git-help[1]](https://git-scm.com/docs/git-help/sv) för mer information, eftersom `git` `--help` ... konverteras internt till `git` `help` ....

[](https://git-scm.com/docs/git/sv#git--Cskvg) [](https://git-scm.com/docs/git/sv#git--Cltskvggt)-C <sökväg>

Kör som om git startades i _< sökväg>_ istället för den aktuella arbetskatalogen. När flera `-C`-alternativ anges, tolkas varje efterföljande icke-absolut `-C` _< sökväg>_ relativt till föregående `-C` _< sökväg>_. Om _< sökväg>_ finns men är tom, t.ex. `-C` `""`, lämnas den aktuella arbetskatalogen oförändrad.
Det här alternativet påverkar alternativ som förväntar sig sökvägsnamn som `--git-dir` och `--work-tree`, i det att deras tolkningar av sökvägsnamnen skulle göras relativa till arbetskatalogen som orsakas av alternativet `-C`. Till exempel är följande anrop likvärdiga:
```
git --git-dir=a.git --work-tree=b -C c status
git --git-dir=c/a.git --work-tree=c/b status
```


[](https://git-scm.com/docs/git/sv#git--cnamnvrde) [](https://git-scm.com/docs/git/sv#git--cltnamngtltvrdegt)-c <namn>=<värde>

Skicka en konfigurationsparameter till kommandot. Det angivna värdet åsidosätter värden från konfigurationsfiler. <namn> förväntas ha samma format som listas av _git config_ (undernycklar separerade med punkter).
Observera att det är tillåtet att utelämna `=` i `git` `-c` `foo.bar` ... och sätter `foo.bar` till det booleska värdet sant (precis som [`foo`]`bar` skulle göra i en konfigurationsfil). Om man inkluderar lika med men med ett tomt värde (som `git` `-c` `foo.bar=` ...) sätter man `foo.bar` till den tomma strängen som `git` `config` `--type=bool` kommer att konvertera till `false`.

[](https://git-scm.com/docs/git/sv#git---config-envnamnmijvar) [](https://git-scm.com/docs/git/sv#git---config-envltnamngtltmijvargt)--config-env=<namn>=<mijövar>

Precis som med `-c` _< namn>_`=`_< värde>_, ge konfigurationsvariabeln _< namn>_ ett värde, där <mijövar> är namnet på en miljövariabel från vilken värdet ska hämtas. Till skillnad från `-c` finns det ingen genväg för att direkt sätta värdet till en tom sträng, istället måste själva miljövariabeln sättas till den tomma strängen. Det är ett fel om _< mijövar>_ inte finns i miljön. _< mijövar>_ får inte innehålla ett likhetstecken för att undvika tvetydighet då _< namn>_ innehåller ett.
Detta är användbart i fall där du vill skicka tillfälliga konfigurationsalternativ till git, men gör det på operativsystem där andra processer kanske kan läsa din kommandorad (t.ex. `/proc/self/cmdline`), men inte din miljö (t.ex. `/proc/self/environ`). Det beteendet är standard på Linux, men kanske inte finns på ditt system.
Observera att detta kan öka säkerheten för variabler som `http.extraHeader` där den känsliga informationen är en del av värdet, men inte t.ex. `url.`_< bas>_`.insteadOf` där den känsliga informationen kan vara en del av nyckeln.

[](https://git-scm.com/docs/git/sv#git---exec-pathskvg) [](https://git-scm.com/docs/git/sv#git---exec-pathltskvggt)--exec-path[=<sökväg>]

Sökväg till var dina kärnprogram i Git är installerade. Detta kan också styras genom att ställa in miljövariabeln GIT_EXEC_PATH. Om ingen sökväg anges kommer _git_ att skriva ut den aktuella inställningen och sedan avsluta.

[](https://git-scm.com/docs/git/sv#git---html-path)--html-path

Skriv ut sökvägen, utan avslutande snedstreck, där Gits HTML-dokumentation är installerad och avsluta.

[](https://git-scm.com/docs/git/sv#git---man-path)--man-path

Skriv ut manualsökvägen (se `man`(`1`)) för manualsidorna för den här versionen av Git och avsluta.

[](https://git-scm.com/docs/git/sv#git---info-path)--info-path

Skriv ut sökvägen där infofilerna som dokumenterar den här versionen av Git är installerade och avsluta.

[](https://git-scm.com/docs/git/sv#git--p)-p


[](https://git-scm.com/docs/git/sv#git---paginate)--paginate

Skicka all utdata till _less_ (eller om angivet, $PAGER) om standardutdata är en terminal. Detta åsidosätter konfigurationsalternativen för `pager.`_< cmd>_ (se avsnittet "Konfigurationsmekanism" nedan).

[](https://git-scm.com/docs/git/sv#git--P)-P


[](https://git-scm.com/docs/git/sv#git---no-pager)--no-pager

Skicka inte Git-utdata till en bläddrare.

[](https://git-scm.com/docs/git/sv#git---git-dirskvg) [](https://git-scm.com/docs/git/sv#git---git-dirltskvggt)--git-dir=<sökväg>

Ange sökvägen till arkivet (".git"-katalogen). Detta kan också styras genom att ange miljövariabeln `GIT_DIR`. Det kan vara en absolut sökväg eller en relativ sökväg till den aktuella arbetskatalogen.
Att ange platsen för katalogen ".git" med hjälp av det här alternativet (eller miljövariabeln `GIT_DIR`) stänger av förvar-upptäckten som försöker hitta en katalog med underkatalogen ".git" (vilket är hur förvaret och den översta nivån i arbetsträdet upptäcks), och talar om för Git att du är på den översta nivån i arbetsträdet. Om du inte är på den översta nivån i arbetskatalogen, bör du tala om för Git var den översta nivån i arbetskatalogen finns, med alternativet `--work-tree=`_< sökväg>_ (eller miljövariabeln `GIT_WORK_TREE`)
Om du bara vill köra git som om det startades i _< sökväg>_, använd då `git` `-C` _< sökväg>_.

[](https://git-scm.com/docs/git/sv#git---work-treeskvg) [](https://git-scm.com/docs/git/sv#git---work-treeltskvggt)--work-tree=<sökväg>

Set the path to the working tree. It can be an absolute path or a path relative to the current working directory. This can also be controlled by setting the GIT_WORK_TREE environment variable and the core.worktree configuration variable (see core.worktree in [git-config[1]](https://git-scm.com/docs/git-config/sv) for a more detailed discussion).

[](https://git-scm.com/docs/git/sv#git---namespaceskvg) [](https://git-scm.com/docs/git/sv#git---namespaceltskvggt)--namespace=<sökväg>

Ställ in Git-namnrymden. Se [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/sv) för mer information. Motsvarar att ställa in miljövariabeln `GIT_NAMESPACE`.

[](https://git-scm.com/docs/git/sv#git---bare)--bare

Behandla förvaret som ett rent bart förvar. Om GIT_DIR-miljön inte är inställd, sätts den till den aktuella arbetskatalogen.

[](https://git-scm.com/docs/git/sv#git---no-replace-objects)--no-replace-objects

Använd inte ersättningsreferenser för att ersätta Git-objekt. Detta motsvarar att exportera miljövariabeln `GIT_NO_REPLACE_OBJECTS` med valfritt värde. Se [git-replace[1]](https://git-scm.com/docs/git-replace/sv) för mer information.

[](https://git-scm.com/docs/git/sv#git---no-lazy-fetch)--no-lazy-fetch

Hämta inte saknade objekt från promisor-fjärr på begäran. Användbart tillsammans med `git` `cat-file` `-e` _< objekt>_ för att se om objektet är lokalt tillgängligt. Detta motsvarar att sätta miljövariabeln `GIT_NO_LAZY_FETCH` till `1`.

[](https://git-scm.com/docs/git/sv#git---no-optional-locks)--no-optional-locks

Utför inte valfria operationer som kräver lås. Detta motsvarar att sätta `GIT_OPTIONAL_LOCKS` till `0`.

[](https://git-scm.com/docs/git/sv#git---no-advice)--no-advice

Inaktivera utskrift av alla rådtips.

[](https://git-scm.com/docs/git/sv#git---literal-pathspecs)--literal-pathspecs

Behandla sökvägsspec bokstavligt (dvs. ingen globbing, ingen pathspec-magi). Detta motsvarar att sätta miljövariabeln `GIT_LITERAL_PATHSPECS` till `1`.

[](https://git-scm.com/docs/git/sv#git---glob-pathspecs)--glob-pathspecs

Lägg till "glob"-magi till alla sökvägsspec. Detta motsvarar att sätta miljövariabeln `GIT_GLOB_PATHSPECS` till `1`. Globbing kan inaktiveras på individuella sökvägsspecar med sökvägsspec-magin ":(literal)"

[](https://git-scm.com/docs/git/sv#git---noglob-pathspecs)--noglob-pathspecs

Lägg till "literal" magi till alla sökvägsspecar. Detta motsvarar att sätta miljövariabeln `GIT_NOGLOB_PATHSPECS` till `1`. Att aktivera globbing på individuella pathspecs kan göras med pathspec magic ":(glob)"

[](https://git-scm.com/docs/git/sv#git---icase-pathspecs)--icase-pathspecs

Lägg till "icase"-magi till alla sökvägsspecar. Detta motsvarar att sätta miljövariabeln `GIT_ICASE_PATHSPECS` till `1`.

[](https://git-scm.com/docs/git/sv#git---list-cmdsgruppgrupp) [](https://git-scm.com/docs/git/sv#git---list-cmdsltgruppgtltgruppgt82308203)--list-cmds=<grupp>[,<grupp>…​]

Lista kommandon efter grupp. Detta är ett internt/experimentellt alternativ och kan komma att ändras eller tas bort i framtiden. Grupper som stöds är: builtins, parseopt (inbyggda kommandon som använder parse-alternativ), deprecated (föråldrade inbyggda kommandon), main (alla kommandon i libexec-katalogen), others (alla andra kommandon i `$PATH` som har git-prefixet), list-<kategori> (se kategorier i command-list.txt), nohelpers (exkluderar hjälpkommandon), alias och config (hämtar kommandolista från konfigurationsvariabeln completion.commands)

[](https://git-scm.com/docs/git/sv#git---attr-sourcetrdlikt) [](https://git-scm.com/docs/git/sv#git---attr-sourcelttrdliktgt)--attr-source=<trädlikt>

Läs gitattributes från <trädlikt> istället för arbetsträdet. Se [gitattributes[5]](https://git-scm.com/docs/gitattributes/sv). Detta motsvarar att ställa in miljövariabeln `GIT_ATTR_SOURCE`.
##  [](https://git-scm.com/docs/git/sv#_git_kommandon)GIT-KOMMANDON
Vi delar in Git i högnivåkommandon ("porslinskommandon") och lågnivå- ("rörmokeri-") kommandon".
##  [](https://git-scm.com/docs/git/sv#_h%C3%B6gniv%C3%A5kommandon_porslin)Högnivåkommandon (porslin)
Vi delar upp porslinskommandona i huvudkommandon och några hjälpprogram.
###  [](https://git-scm.com/docs/git/sv#_main_porcelain_commands)Main porcelain commands
Warning |  Missing `sv/{build_dir}/cmds-mainporcelain.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/sv#_till%C3%A4ggskommandon)Tilläggskommandon
Manipulatörer:
Warning |  Missing `sv/{build_dir}/cmds-ancillarymanipulators.adoc` See original version for this content.
---|---
Interrogators:
Warning |  Missing `sv/{build_dir}/cmds-ancillaryinterrogators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/sv#_interaktion_med_andra)Interaktion med andra
Dessa kommandon är till för att interagera med främmande SCM och med andra personer via patch via e-post.
Warning |  Missing `sv/{build_dir}/cmds-foreignscminterface.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/sv#_nollst%C3%A4ll_%C3%A5terst%C3%A4ll_och_%C3%A5ngring)Nollställ, återställ och ångring
Det finns tre kommandon med liknande namn: `git` `reset`, `git` `restore` och `git` `revert`.
  * [git-revert[1]](https://git-scm.com/docs/git-revert/sv) handlar om att skapa en ny incheckning som återställer ändringar gjorda av andra incheckning.
  * [git-restore[1]](https://git-scm.com/docs/git-restore/sv) handlar om att återställa filer i arbetskatalog från antingen indexet eller en annan incheckning. Det här kommandot uppdaterar inte din gren. Kommandot kan också användas för att återställa filer i indexet från en annan incheckning.
  * [git-reset[1]](https://git-scm.com/docs/git-reset/sv) handlar om att uppdatera din branch, flytta topen för att lägga till eller ta bort incheckningar från grenen. Denna operation ändrar inchecknings-historiken.
`git` `reset` kan också användas för att återställa indexet, överlappande med `git` `restore`.


##  [](https://git-scm.com/docs/git/sv#_l%C3%A5gniv%C3%A5kommandon_r%C3%B6rmokeri)Lågnivåkommandon (rörmokeri)
Även om Git inkluderar sitt eget porslinslager, är dess lågnivåkommandon tillräckliga för att stödja utvecklingen av alternativa porslinstyper. Utvecklare av sådana porslinstyper kan börja med att läsa om [git-update-index[1]](https://git-scm.com/docs/git-update-index/sv) och [git-read-tree[1]](https://git-scm.com/docs/git-read-tree/sv).
Gränssnittet (indata, utdata, uppsättning alternativ och semantiken) till dessa lågnivåkommandon är avsedda att vara mycket mer stabilt än kommandon på porslinsnivå, eftersom dessa kommandon främst är för skriptbaserad användning. Gränssnittet till porslinskommandon kan däremot komma att ändras för att förbättra slutanvändarupplevelsen.
Följande beskrivning delar upp lågnivåkommandon i kommandon som manipulerar objekt (i förvar, indexet och arbetskatalog), kommandon som förhör och jämför objekt, och kommandon som flyttar objekt och referenser mellan arkiv.
###  [](https://git-scm.com/docs/git/sv#_manipulationskommandon)Manipulationskommandon
Warning |  Missing `sv/{build_dir}/cmds-plumbingmanipulators.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/sv#_f%C3%B6rh%C3%B6rskommandon)Förhörskommandon
Warning |  Missing `sv/{build_dir}/cmds-plumbinginterrogators.adoc` See original version for this content.
---|---
I allmänhet berör inte förhörs-kommandon filerna i arbetskatalogen.
###  [](https://git-scm.com/docs/git/sv#_synkronisera_f%C3%B6rvar)Synkronisera förvar
Warning |  Missing `sv/{build_dir}/cmds-synchingrepositories.adoc` See original version for this content.
---|---
Följande är hjälpkommandon som används av ovanstående; slutanvändare använder dem vanligtvis inte direkt.
Warning |  Missing `sv/{build_dir}/cmds-synchelpers.adoc` See original version for this content.
---|---
###  [](https://git-scm.com/docs/git/sv#_interna_hj%C3%A4lpkommandon)Interna hjälpkommandon
Dessa är interna hjälpkommandon som används av andra kommandon; slutanvändare använder dem vanligtvis inte direkt.
Warning |  Missing `sv/{build_dir}/cmds-purehelpers.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/sv#_guider)Guider
Följande dokumentationssidor är guider om Git-koncept.
Warning |  Missing `sv/{build_dir}/cmds-guide.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/sv#_gr%C3%A4nssnitt_f%C3%B6r_f%C3%B6rvar_kommandon_och_filer)Gränssnitt för förvar, kommandon och filer
Denna dokumentation diskuterar gränssnitt för förvar och kommandon som användare förväntas interagera direkt med. Se `--user-formats` i [git-help[1]](https://git-scm.com/docs/git-help/sv) för mer information om kriterierna.
Warning |  Missing `sv/{build_dir}/cmds-userinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/sv#_filformat_protokoll_och_andra_utvecklargr%C3%A4nssnitt)Filformat, protokoll och andra utvecklargränssnitt
Denna dokumentation diskuterar filformat, över kabeln-protokoll och andra Git-utvecklargränssnitt. Se `--developer-interfaces` i [git-help[1]](https://git-scm.com/docs/git-help/sv).
Warning |  Missing `sv/{build_dir}/cmds-developerinterfaces.adoc` See original version for this content.
---|---
##  [](https://git-scm.com/docs/git/sv#_konfigurationsmekanism)Konfigurationsmekanism
Git använder ett enkelt textformat för att lagra anpassningar som är per förvar och per användare. En sådan konfigurationsfil kan se ut så här:
```
#
# Ett '#'- eller ';'-teckne anger en kommentar.
#

; kärnvariabler
[core]
	; Lita inte på fillägen
	filemode = false

; användaridentitet
[user]
	name = "Junio C Hamano"
	email = "gitster@pobox.com"
```

Olika kommandon läses från konfigurationsfilen och justerar sin funktion därefter. Se [git-config[1]](https://git-scm.com/docs/git-config/sv) för en lista och mer information om konfigurationsmekanismen.
##  [](https://git-scm.com/docs/git/sv#_identifierare_terminologi)Identifierare Terminologi

[](https://git-scm.com/docs/git/sv#git-objekt) [](https://git-scm.com/docs/git/sv#git-ltobjektgt)<objekt>

Anger objektnamnet för alla typer av objekt.

[](https://git-scm.com/docs/git/sv#git-blob) [](https://git-scm.com/docs/git/sv#git-ltblobgt)<blob>

Anger ett blob-objektnamn.

[](https://git-scm.com/docs/git/sv#git-trd) [](https://git-scm.com/docs/git/sv#git-lttrdgt)<träd>

Indikerar ett trädobjektnamn.

[](https://git-scm.com/docs/git/sv#git-incheckning) [](https://git-scm.com/docs/git/sv#git-ltincheckninggt)<incheckning>

Indikerar ett inchecknings-objektnamn.

[](https://git-scm.com/docs/git/sv#git-trdlikt) [](https://git-scm.com/docs/git/sv#git-lttrdliktgt)<trädlikt>

Indikerar ett träd-, inchecknings- eller taggobjektnamn. Ett kommando som tar ett <trädlikt>-argument vill i slutändan operera på ett <tree>-objekt men avreferenserar automatiskt <inchecknings>- och <tag>-objekt som pekar på ett <träd>.

[](https://git-scm.com/docs/git/sv#git-inchecknings-aktig) [](https://git-scm.com/docs/git/sv#git-ltinchecknings-aktiggt)<inchecknings-aktig>

Indikerar ett inchecknings- eller tag-objektnamn. Ett kommando som tar ett <inchecknings-aktig>-argument vill i slutändan utföra en åtgärd på ett <inchecknings>-objekt men avreferenserar automatiskt <tag>-objekt som pekar på en <incheckning>.

[](https://git-scm.com/docs/git/sv#git-typ) [](https://git-scm.com/docs/git/sv#git-lttypgt)<typ>

Indikerar att en objekttyp krävs. För närvarande en av: `blob`, `tree`, `commit` eller `tag`.

[](https://git-scm.com/docs/git/sv#git-fil) [](https://git-scm.com/docs/git/sv#git-ltfilgt)<fil>

Indikerar ett filnamn - nästan alltid relativt till roten av trädstrukturen som `GIT_INDEX_FILE` beskriver.
##  [](https://git-scm.com/docs/git/sv#_symboliska_identifierare)Symboliska identifierare
Alla Git-kommandon som accepterar valfritt <objekt> kan också använda följande symboliska notation:

[](https://git-scm.com/docs/git/sv#git-HEAD)HEAD

indikerar chefen för den nuvarande grenen.

[](https://git-scm.com/docs/git/sv#git-tagg) [](https://git-scm.com/docs/git/sv#git-lttagggt)<tagg>

ett giltigt tagg-_namn_ (dvs. en `refs/tags/`_< tag>_-referens).

[](https://git-scm.com/docs/git/sv#git-huvud) [](https://git-scm.com/docs/git/sv#git-lthuvudgt)<huvud>

ett giltigt huvud-_namn_ (dvs. en `refs/heads/`_< huvud>_-referens).
För en mer komplett lista över hur man stavar objektnamn, se avsnittet "SPECIFICERING AV REVISIONER" i [gitrevisions[7]](https://git-scm.com/docs/gitrevisions/sv).
##  [](https://git-scm.com/docs/git/sv#_fil_katalogstruktur)Fil-/katalogstruktur
Se dokumentet [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/sv).
Läs [githooks[5]](https://git-scm.com/docs/githooks/sv) för mer information om varje krok.
SCM:er på högre nivå kan tillhandahålla och hantera ytterligare information i `$GIT_DIR`.
##  [](https://git-scm.com/docs/git/sv#_terminologi)Terminologi
Please see [gitglossary[7]](https://git-scm.com/docs/gitglossary/sv).
##  [](https://git-scm.com/docs/git/sv#_milj%C3%B6variabler)Miljövariabler
Various Git commands pay attention to environment variables and change their behavior. The environment variables marked as "Boolean" take their values the same way as Boolean valued configuration variables, i.e., "true", "yes", "on" and positive numbers are taken as "yes", while "false", "no", "off", and "0" are taken as "no".
Här är variablerna:
###  [](https://git-scm.com/docs/git/sv#_system)System

[](https://git-scm.com/docs/git/sv#git-HOME) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeHOMEcodespan)`HOME`

Anger sökvägen till användarens hemkatalog. Om den inte är inställd i Windows kommer Git att sätta en processmiljövariabel lika med: `$HOMEDRIVE$HOMEPATH` om både `$HOMEDRIVE` och `$HOMEPATH` finns; annars `$USERPROFILE` om `$USERPROFILE` finns.
###  [](https://git-scm.com/docs/git/sv#_git_f%C3%B6rvar)Git-förvar
Dessa miljövariabler gäller för "alla" centrala Git-kommandon. Obs: det är värt att notera att de kan användas/åsidosättas av SCMS som sitter ovanför Git, så var försiktig om du använder ett främmande framända.

[](https://git-scm.com/docs/git/sv#git-GITINDEXFILE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITINDEXFILEcodespan)`GIT_INDEX_FILE`

Denna miljövariabel anger en alternativ indexfil. Om den inte anges används standardvärdet `$GIT_DIR/index`.

[](https://git-scm.com/docs/git/sv#git-GITINDEXVERSION) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITINDEXVERSIONcodespan)`GIT_INDEX_VERSION`

Denna miljövariabel anger vilken indexversion som används när indexfilen skrivs ut. Den påverkar inte befintliga indexfiler. Som standard används indexfilversion 2 eller 3. Se [git-update-index[1]](https://git-scm.com/docs/git-update-index/sv) för mer information.

[](https://git-scm.com/docs/git/sv#git-GITOBJECTDIRECTORY) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITOBJECTDIRECTORYcodespan)`GIT_OBJECT_DIRECTORY`

Om objektlagringskatalogen anges via denna miljövariabel skapas sha1-katalogerna under - annars används standardkatalogen `$GIT_DIR/objects`.

[](https://git-scm.com/docs/git/sv#git-GITALTERNATEOBJECTDIRECTORIES) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITALTERNATEOBJECTDIRECTORIEScodespan)`GIT_ALTERNATE_OBJECT_DIRECTORIES`

På grund av Git-objektens oföränderliga natur kan gamla objekt arkiveras i delade, skrivskyddade kataloger. Denna variabel anger en ":"-separerad (i Windows ";"-separerad) lista över Git-objektkataloger som kan användas för att söka efter Git-objekt. Nya objekt kommer inte att skrivas till dessa kataloger.
Poster som börjar med `"` (dubbla citattecken) tolkas som C-liknande citattecken, vilket tar bort inledande och efterföljande dubbla citattecken och respekterar omvända snedstreck. Till exempel har värdet _"sökväg-med-\"-och-:-i-den":vanilla-sökväg_ två sökvägar: _sökväg-med-"-och-:-i-den_ och _vanilla-sökväg_.

[](https://git-scm.com/docs/git/sv#git-GITDIR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDIRcodespan)`GIT_DIR`

Om miljövariabeln `GIT_DIR` är satt anger den en sökväg som ska användas istället för standardvariabeln `.git` för basen av förvaret. Kommandoradsalternativet `--git-dir` ställer också in detta värde.

[](https://git-scm.com/docs/git/sv#git-GITWORKTREE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITWORKTREEcodespan)`GIT_WORK_TREE`

Ange sökvägen till roten av arbetsträdet. Detta kan också styras av kommandoradsalternativet `--work-tree` och konfigurationsvariabeln core.worktree.

[](https://git-scm.com/docs/git/sv#git-GITNAMESPACE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITNAMESPACEcodespan)`GIT_NAMESPACE`

Ställ in Git-namnrymden; se [gitnamespaces[7]](https://git-scm.com/docs/gitnamespaces/sv) för mer information. Kommandoradsalternativet `--namespace` ställer också in detta värde.

[](https://git-scm.com/docs/git/sv#git-GITCEILINGDIRECTORIES) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCEILINGDIRECTORIEScodespan)`GIT_CEILING_DIRECTORIES`

Detta bör vara en kolonseparerad lista med absoluta sökvägar. Om den är angiven är det en lista över kataloger som Git inte ska söka upp till när den letar efter en förvar-katalog (användbart för att exkludera långsamt laddande nätverkskataloger). Den kommer inte att exkludera den aktuella arbetskatalogen eller en GIT_DIR-uppsättning på kommandoraden eller i miljön. Normalt måste Git läsa posterna i den här listan och matcha eventuella symboliska länkar som kan finnas för att jämföra dem med den aktuella katalogen. Men om även denna åtkomst är långsam kan du lägga till en tom post i listan för att tala om för Git att de efterföljande posterna inte är symboliska länkar och inte behöver matchas; t.ex. `GIT_CEILING_DIRECTORIES=/maybe/symlink::/very/slow/non/symlink`.

[](https://git-scm.com/docs/git/sv#git-GITDISCOVERYACROSSFILESYSTEM) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDISCOVERYACROSSFILESYSTEMcodespan)`GIT_DISCOVERY_ACROSS_FILESYSTEM`

När Git körs i en katalog som inte har ".git"-förvar-katalogen, försöker den hitta en sådan katalog i överordnade kataloger för att hitta toppen av arbetsträdet, men som standard korsar den inte filsystemsgränser. Denna booleska miljövariabel kan sättas till true för att ange att Git inte ska stanna vid filsystemsgränser. Liksom `GIT_CEILING_DIRECTORIES` kommer detta inte att påverka en explicit arkivkatalog som anges via `GIT_DIR` eller på kommandoraden.

[](https://git-scm.com/docs/git/sv#git-GITCOMMONDIR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCOMMONDIRcodespan)`GIT_COMMON_DIR`

Om den här variabeln är satt till en sökväg, kommer filer som inte är arbetsträd och som normalt finns i $GIT_DIR att hämtas från den här sökvägen istället. Arbetsträdspecifika filer som HEAD eller index hämtas från $GIT_DIR. Se [gitrepository-layout[5]](https://git-scm.com/docs/gitrepository-layout/sv) och [git-worktree[1]](https://git-scm.com/docs/git-worktree/sv) för mer information. Den här variabeln har lägre prioritet än andra sökvägsvariabler som GIT_INDEX_FILE, GIT_OBJECT_DIRECTORY…​

[](https://git-scm.com/docs/git/sv#git-GITDEFAULTHASH) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDEFAULTHASHcodespan)`GIT_DEFAULT_HASH`

Om denna variabel är satt kommer standard hashalgoritmen för nya förvar att ställas in på detta värde. Detta värde ignoreras vid kloning och inställningen för fjärrförvar används alltid. Standardvärdet är "sha1". Se `--object-format` i [git-init[1]](https://git-scm.com/docs/git-init/sv).

[](https://git-scm.com/docs/git/sv#git-GITDEFAULTREFFORMAT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDEFAULTREFFORMATcodespan)`GIT_DEFAULT_REF_FORMAT`

Om den här variabeln är satt, kommer standard-referens bakända formatet för nya förvar att ställas in på detta värde. Standardvärdet är "files". Se `--ref-format` i [git-init[1]](https://git-scm.com/docs/git-init/sv).
###  [](https://git-scm.com/docs/git/sv#_git_incheckningar)Git-incheckningar

[](https://git-scm.com/docs/git/sv#git-GITAUTHORNAME) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITAUTHORNAMEcodespan)`GIT_AUTHOR_NAME`

Det människoläsbara namnet som används i författaridentiteten när man skapar incheckning- eller taggobjekt, eller när man skriver refloggar. Åsidosätter konfigurationsinställningarna `user.name` och `author.name`.

[](https://git-scm.com/docs/git/sv#git-GITAUTHOREMAIL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITAUTHOREMAILcodespan)`GIT_AUTHOR_EMAIL`

E-postadressen som används i författaridentiteten när man skapar incheckning- eller taggobjekt, eller när man skriver refloggar. Åsidosätter konfigurationsinställningarna `user.email` och `author.email`.

[](https://git-scm.com/docs/git/sv#git-GITAUTHORDATE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITAUTHORDATEcodespan)`GIT_AUTHOR_DATE`

Datumet som används för författaridentiteten när man skapar incheckning- eller taggobjekt, eller när man skriver refloggar. Se [git-commit[1]](https://git-scm.com/docs/git-commit/sv) för giltiga format.

[](https://git-scm.com/docs/git/sv#git-GITCOMMITTERNAME) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCOMMITTERNAMEcodespan)`GIT_COMMITTER_NAME`

Det människoläsbara namnet som används i inchecknings-identiteten när incheckning- eller taggobjekt skapas, eller när refloggar skrivs. Åsidosätter konfigurationsinställningarna `user.name` och `committer.name`.

[](https://git-scm.com/docs/git/sv#git-GITCOMMITTEREMAIL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCOMMITTEREMAILcodespan)`GIT_COMMITTER_EMAIL`

E-postadressen som används i författaridentiteten när man skapar incheckning- eller taggobjekt, eller när man skriver refloggar. Åsidosätter konfigurationsinställningarna `user.email` och `committer.email`.

[](https://git-scm.com/docs/git/sv#git-GITCOMMITTERDATE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCOMMITTERDATEcodespan)`GIT_COMMITTER_DATE`

Datumet som används för incheckare-identiteten när inchecknings- eller taggobjekt skapas, eller när reflogs skrivs. Se [git-commit[1]](https://git-scm.com/docs/git-commit/sv) för giltiga format.

[](https://git-scm.com/docs/git/sv#git-EMAIL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeEMAILcodespan)`EMAIL`

E-postadressen som används i författar- och incheckare-identiteterna om ingen annan relevant miljövariabel eller konfigurationsinställning har angetts.
###  [](https://git-scm.com/docs/git/sv#_git_differenser)Git-differenser

[](https://git-scm.com/docs/git/sv#git-GITDIFFOPTS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDIFFOPTScodespan)`GIT_DIFF_OPTS`

Den enda giltiga inställningen är "--unified=??" eller "-u??" för att ange antalet kontextrader som visas när en enhetlig diff skapas. Detta har företräde framför alla alternativvärden "-U" eller "--unified" som skickas på Git diff-kommandoraden.

[](https://git-scm.com/docs/git/sv#git-GITEXTERNALDIFF) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITEXTERNALDIFFcodespan)`GIT_EXTERNAL_DIFF`

När miljövariabeln `GIT_EXTERNAL_DIFF` är satt, anropas programmet som namnges av den för att generera differ, och Git använder inte dess inbyggda diff-maskineri. För en sökväg som läggs till, tas bort eller ändras, anropas `GIT_EXTERNAL_DIFF` med 7 parametrar:
```
sökväg gammal-fil gammal-hex gammalt-läge ny-fil ny-hex nytt-läge
```

där:

[](https://git-scm.com/docs/git/sv#git-gammalny-fil) [](https://git-scm.com/docs/git/sv#git-ltgammalnygt-fil)<gammal|ny>-fil

är filer som GIT_EXTERNAL_DIFF kan använda för att läsa innehållet i <gammal|ny>,

[](https://git-scm.com/docs/git/sv#git-gammalny-hex) [](https://git-scm.com/docs/git/sv#git-ltgammalnygt-hex)<gammal|ny>-hex

är de 40 hexsiffriga SHA-1-hashen,

[](https://git-scm.com/docs/git/sv#git-gammaltnytt-lge) [](https://git-scm.com/docs/git/sv#git-ltgammaltnyttgt-lge)<gammalt|nytt>-läge

är den oktala representationen av fillägena.
Filparametrarna kan peka på användarens arbetsfil (t.ex. `new-file` i "git-diff-files"), `/dev/null` (t.ex. `old-file` när en ny fil läggs till), eller en temporär fil (t.ex. `gammal-fil` i indexet). `GIT_EXTERNAL_DIFF` behöver inte oroa sig för att koppla bort den temporära filen — den tas bort när `GIT_EXTERNAL_DIFF` avslutas.
För en sökväg som är osammanslagen anropas `GIT_EXTERNAL_DIFF` med 1 parameter, <sökväg>.
För varje sökväg som `GIT_EXTERNAL_DIFF` anropas sätts två miljövariabler, `GIT_DIFF_PATH_COUNTER` och `GIT_DIFF_PATH_TOTAL`.

[](https://git-scm.com/docs/git/sv#git-GITEXTERNALDIFFTRUSTEXITCODE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITEXTERNALDIFFTRUSTEXITCODEcodespan)`GIT_EXTERNAL_DIFF_TRUST_EXIT_CODE`

Om denna booleska miljövariabel är satt till sant förväntas kommandot `GIT_EXTERNAL_DIFF` returnera avslutningskod 0 om det anser att indatafilerna är lika eller 1 om det anser att de är olika, som `diff`(`1`). Om det är satt till falskt, vilket är standardvärdet, förväntas kommandot returnera avslutningskod 0 oavsett likhet. All annan avslutningskod gör att Git rapporterar ett allvarligt fel.

[](https://git-scm.com/docs/git/sv#git-GITDIFFPATHCOUNTER) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDIFFPATHCOUNTERcodespan)`GIT_DIFF_PATH_COUNTER`

En 1-baserad räknare som ökas med ett för varje väg.

[](https://git-scm.com/docs/git/sv#git-GITDIFFPATHTOTAL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITDIFFPATHTOTALcodespan)`GIT_DIFF_PATH_TOTAL`

Det totala antalet sökvägar.
###  [](https://git-scm.com/docs/git/sv#_andra)andra

[](https://git-scm.com/docs/git/sv#git-GITMERGEVERBOSITY) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITMERGEVERBOSITYcodespan)`GIT_MERGE_VERBOSITY`

Ett tal som styr mängden utdata som visas av den rekursiva sammanslagings-strategin. Åsidosätter merge.verbosity. Se [git-merge[1]](https://git-scm.com/docs/git-merge/sv)

[](https://git-scm.com/docs/git/sv#git-GITPAGER) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITPAGERcodespan)`GIT_PAGER`

Denna miljövariabel åsidosätter `$PAGER`. Om den är satt till en tom sträng eller till värdet "cat" kommer Git inte att starta en bläddrae. Se även alternativet `core.pager` i [git-config[1]](https://git-scm.com/docs/git-config/sv).

[](https://git-scm.com/docs/git/sv#git-GITPROGRESSDELAY) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITPROGRESSDELAYcodespan)`GIT_PROGRESS_DELAY`

Ett tal som styr hur många sekunders fördröjning sak förflyta innan valfria förloppsindikatorer visas. Standardvärdet är 1.

[](https://git-scm.com/docs/git/sv#git-GITEDITOR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITEDITORcodespan)`GIT_EDITOR`

Denna miljövariabel åsidosätter `$EDITOR` och `$VISUAL`. Den används av flera Git-kommandon när en editor ska startas i interaktivt läge. Se även [git-var[1]](https://git-scm.com/docs/git-var/sv) och alternativet `core.editor` i [git-config[1]](https://git-scm.com/docs/git-config/sv).

[](https://git-scm.com/docs/git/sv#git-GITSEQUENCEEDITOR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITSEQUENCEEDITORcodespan)`GIT_SEQUENCE_EDITOR`

Denna miljövariabel åsidosätter den konfigurerade Git-editorn när att-göra-listan för en interaktiv ombasering redigeras. Se även [git-rebase[1]](https://git-scm.com/docs/git-rebase/sv) och alternativet `sequence.editor` i [git-config[1]](https://git-scm.com/docs/git-config/sv).

[](https://git-scm.com/docs/git/sv#git-GITSSH) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITSSHcodespan)`GIT_SSH`


[](https://git-scm.com/docs/git/sv#git-GITSSHCOMMAND) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITSSHCOMMANDcodespan)`GIT_SSH_COMMAND`

Om någon av dessa miljövariabler är satt kommer _git fetch_ och _git push_ att använda det angivna kommandot istället för _ssh_ när de behöver ansluta till ett fjärrsystem. Kommandoradsparametrarna som skickas till det konfigurerade kommandot bestäms av ssh-varianten. Se alternativet `ssh.variant` i [git-config[1]](https://git-scm.com/docs/git-config/sv) för mer information.
`$GIT_SSH_COMMAND` har företräde framför `$GIT_SSH` och tolkas av skalet, vilket tillåter att ytterligare argument inkluderas. `$GIT_SSH` måste å andra sidan bara vara sökvägen till ett program (vilket kan vara ett wrapper-shellskript om ytterligare argument behövs).
Vanligtvis är det enklare att konfigurera önskade alternativ via din personliga `.ssh/config`-fil. Vänligen se din ssh-dokumentation för mer information.

[](https://git-scm.com/docs/git/sv#git-GITSSHVARIANT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITSSHVARIANTcodespan)`GIT_SSH_VARIANT`

Om denna miljövariabel är satt, åsidosätter den Gits autodetektering av om `GIT_SSH`/`GIT_SSH_COMMAND`/`core.sshCommand` refererar till OpenSSH, plink eller tortoiseplink. Denna variabel åsidosätter konfigurationsinställningen `ssh.variant` som tjänar samma syfte.

[](https://git-scm.com/docs/git/sv#git-GITSSLNOVERIFY) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITSSLNOVERIFYcodespan)`GIT_SSL_NO_VERIFY`

Att ställa in och exportera denna miljövariabel till valfritt värde anger att Git inte ska verifiera SSL-certifikatet vid hämtning- eller sändnings-överföring över HTTPS.

[](https://git-scm.com/docs/git/sv#git-GITATTRSOURCE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITATTRSOURCEcodespan)`GIT_ATTR_SOURCE`

Ställer in trädstrukturen som gitattributes ska läsas från.

[](https://git-scm.com/docs/git/sv#git-GITASKPASS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITASKPASScodespan)`GIT_ASKPASS`

Om denna miljövariabel är satt, kommer Git-kommandon som behöver hämta lösenord eller lösenfraser (t.ex. för HTTP- eller IMAP-autentisering) att anropa detta program med en lämplig prompt som kommandoradsargument och läsa lösenordet från dess STDOUT. Se även alternativet `core.askPass` i [git-config[1]](https://git-scm.com/docs/git-config/sv).

[](https://git-scm.com/docs/git/sv#git-GITTERMINALPROMPT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTERMINALPROMPTcodespan)`GIT_TERMINAL_PROMPT`

Om denna booleska miljövariabel är satt till falskt, kommer git inte att fråga i terminalen (t.ex. när man frågar efter HTTP-autentisering).

[](https://git-scm.com/docs/git/sv#git-GITCONFIGGLOBAL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCONFIGGLOBALcodespan)`GIT_CONFIG_GLOBAL`


[](https://git-scm.com/docs/git/sv#git-GITCONFIGSYSTEM) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCONFIGSYSTEMcodespan)`GIT_CONFIG_SYSTEM`

Hämta konfigurationen från de givna filerna istället från globala eller systemnivåkonfigurationsfiler. Om `GIT_CONFIG_SYSTEM` är satt kommer inte systemkonfigurationsfilen som definierades vid byggtillfället (vanligtvis `/etc/gitconfig`) att läsas. Likaså, om `GIT_CONFIG_GLOBAL` är satt, kommer varken `$HOME/.gitconfig` eller `$XDG_CONFIG_HOME/git/config` att läsas. Kan ställas in på `/dev/null` för att hoppa över läsning av konfigurationsfiler för respektive nivå.

[](https://git-scm.com/docs/git/sv#git-GITCONFIGNOSYSTEM) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCONFIGNOSYSTEMcodespan)`GIT_CONFIG_NOSYSTEM`

Om läsning av inställningar från den systemomfattande `$`(`prefix`)`/etc/gitconfig`-filen ska hoppas över. Denna booleska miljövariabel kan användas tillsammans med `$HOME` och `$XDG_CONFIG_HOME` för att skapa en förutsägbar miljö för ett kräsna skript, eller så kan du ställa in den på true för att tillfälligt undvika att använda en buggig `/etc/gitconfig`-fil medan du väntar på att någon med tillräckliga behörigheter ska åtgärda den.

[](https://git-scm.com/docs/git/sv#git-GITFLUSH) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITFLUSHcodespan)`GIT_FLUSH`

Om denna booleska miljövariabel är satt till sant, kommer kommandon som _git blame_ (i inkrementellt läge), _git rev-list_ , _git log_ , _git check-attr_ och _git check-ignore_ att tvinga fram en rensning av utdataströmmen efter att varje post har rensats. Om denna variabel är satt till falskt, kommer utdata från dessa kommandon att ske med hjälp av helt buffrad I/O. Om denna miljövariabel inte är satt, kommer Git att välja buffrad eller postorienterad rensning baserat på om stdout verkar omdirigeras till en fil eller inte.

[](https://git-scm.com/docs/git/sv#git-GITTRACE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEcodespan)`GIT_TRACE`

Aktiverar allmänna spårningsmeddelanden, t.ex. aliasexpansion, inbyggd kommandokörning och extern kommandokörning.
Om den här variabeln är satt till "1", "2" eller "sant" (jämförelsen är inte skiftlägeskänslig) kommer spårningsmeddelanden att skrivas ut till stderr.
Om variabeln är satt till ett heltal större än 2 och lägre än 10 (strikt) kommer Git att tolka detta värde som en öppen fildeskriptor och försöka skriva spårningsmeddelandena till denna fildeskriptor.
Alternativt, om variabeln är satt till en absolut sökväg (som börjar med tecknet _/_), kommer Git att tolka detta som en filsökväg och försöka lägga till spårningsmeddelandena till den.
Att avaktivera variabeln, eller att sätta den till tom, "0" eller "false" (okänsligt för gemener och versaler) inaktiverar spårningsmeddelanden.

[](https://git-scm.com/docs/git/sv#git-GITTRACEFSMONITOR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEFSMONITORcodespan)`GIT_TRACE_FSMONITOR`

Aktiverar spårningsmeddelanden för filsystemövervakningsutvidgningen. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACEPACKACCESS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEPACKACCESScodespan)`GIT_TRACE_PACK_ACCESS`

Aktiverar spårningsmeddelanden för alla åtkomster till alla paket. För varje åtkomst registreras paketets filnamn och en offset i paketet. Detta kan vara användbart för felsökning av vissa paketrelaterade prestandaproblem. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACEPACKET) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEPACKETcodespan)`GIT_TRACE_PACKET`

Aktiverar spårningsmeddelanden för alla paket som kommer in i eller ut ur ett givet program. Detta kan hjälpa till med felsökning av objektförhandling eller andra protokollproblem. Spårning avstängs vid ett paket som börjar med "PACK" (men se `GIT_TRACE_PACKFILE` nedan). Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACEPACKFILE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEPACKFILEcodespan)`GIT_TRACE_PACKFILE`

Möjliggör spårning av packfiler som skickats eller mottagits av ett givet program. Till skillnad från annan spårningsutdata är denna spårning ordagrant: inga rubriker och ingen citering av binär data. Du vill nästan säkert dirigera till en fil (t.ex. `GIT_TRACE_PACKFILE=/tmp/my.pack`) snarare än att visa den i terminalen eller blanda den med annan spårningsutdata.
Observera att detta för närvarande endast är implementerat för klientsidan av kloner och hämtningar.

[](https://git-scm.com/docs/git/sv#git-GITTRACEPERFORMANCE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEPERFORMANCEcodespan)`GIT_TRACE_PERFORMANCE`

Aktiverar prestandarelaterade spårningsmeddelanden, t.ex. total exekveringstid för varje Git-kommando. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACEREFS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEREFScodespan)`GIT_TRACE_REFS`

Aktiverar spårningsmeddelanden för operationer på referensdatabasen. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACESETUP) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACESETUPcodespan)`GIT_TRACE_SETUP`

Enables trace messages printing the .git, working tree and current working directory after Git has completed its setup phase. See `GIT_TRACE` for available trace output options.

[](https://git-scm.com/docs/git/sv#git-GITTRACESHALLOW) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACESHALLOWcodespan)`GIT_TRACE_SHALLOW`

Aktiverar spårningsmeddelanden som kan hjälpa till med felsökning vid hämtning/kloning av ytliga arkiv. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACECURL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACECURLcodespan)`GIT_TRACE_CURL`

Aktiverar en curl fullständig spårdump av all inkommande och utgående data, inklusive beskrivande information, för git-transportprotokollet. Detta liknar att göra curl `--trace-ascii` på kommandoraden. Se `GIT_TRACE` för tillgängliga spårningsutdataalternativ.

[](https://git-scm.com/docs/git/sv#git-GITTRACECURLNODATA) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACECURLNODATAcodespan)`GIT_TRACE_CURL_NO_DATA`

När en curl-spårning är aktiverad (se `GIT_TRACE_CURL` ovan), dumpa inte data (det vill säga, dumpa endast informationsrader och rubriker).

[](https://git-scm.com/docs/git/sv#git-GITTRACE2) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACE2codespan)`GIT_TRACE2`

Möjliggör mer detaljerade spårningsmeddelanden från biblioteket "trace2". Utdata från `GIT_TRACE2` är ett enkelt textbaserat format för mänsklig läsbarhet.
Om den här variabeln är satt till "1", "2" eller "sant" (jämförelsen är inte skiftlägeskänslig) kommer spårningsmeddelanden att skrivas ut till stderr.
Om variabeln är satt till ett heltal större än 2 och lägre än 10 (strikt) kommer Git att tolka detta värde som en öppen fildeskriptor och försöka skriva spårningsmeddelandena till denna fildeskriptor.
Alternativt, om variabeln är satt till en absolut sökväg (som börjar med tecknet _/_), kommer Git att tolka detta som en filsökväg och försöka lägga till spårningsmeddelandena till den. Om sökvägen redan finns och är en katalog, kommer spårningsmeddelandena att skrivas till filer (en per process) i den katalogen, namngivna enligt den sista komponenten i SID och en valfri räknare (för att undvika filnamnskollisioner).
Om variabeln dessutom är satt till `af_unix:`[_< socket-typ>_`:`]_< absolut-sökväg>_, kommer Git att försöka öppna sökvägen som en Unix Domain Socket. Sockettypen kan vara antingen `stream` eller `dgram`.
Att avaktivera variabeln, eller att sätta den till tom, "0" eller "false" (okänsligt för gemener och versaler) inaktiverar spårningsmeddelanden.
Se [Trace2-dokumentation](https://git-scm.com/docs/api-trace2/sv) för fullständig information.

[](https://git-scm.com/docs/git/sv#git-GITTRACE2EVENT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACE2EVENTcodespan)`GIT_TRACE2_EVENT`

Den här inställningen skriver ett JSON-baserat format som är lämpligt för maskintolkning. Se `GIT_TRACE2` för tillgängliga spårningsutdataalternativ och [Trace2-dokumentation](https://git-scm.com/docs/api-trace2/sv) för fullständig information.

[](https://git-scm.com/docs/git/sv#git-GITTRACE2PERF) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACE2PERFcodespan)`GIT_TRACE2_PERF`

Utöver de textbaserade meddelanden som finns tillgängliga i `GIT_TRACE2`, skriver den här inställningen ett kolumnbaserat format för att förstå kapslade regioner. Se `GIT_TRACE2` för tillgängliga spårningsutdataalternativ och [Trace2-dokumentation](https://git-scm.com/docs/api-trace2/sv) för fullständig information.

[](https://git-scm.com/docs/git/sv#git-GITTRACEREDACT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITTRACEREDACTcodespan)`GIT_TRACE_REDACT`

Som standard, när spårning är aktiverat, redigerar Git värdena för cookies, "Authorization:"-headern, "Proxy-Authorization:"-headern och packfile-URI:er. Sätt denna booleska miljövariabel till falsk för att förhindra denna redigering.

[](https://git-scm.com/docs/git/sv#git-GITNOREPLACEOBJECTS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITNOREPLACEOBJECTScodespan)`GIT_NO_REPLACE_OBJECTS`

Att ställa in och exportera denna miljövariabel anger att Git ska ignorera ersättningsreferenser och inte ersätta Git-objekt.

[](https://git-scm.com/docs/git/sv#git-GITLITERALPATHSPECS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITLITERALPATHSPECScodespan)`GIT_LITERAL_PATHSPECS`

Om du ställer in denna booleska miljövariabel till sant kommer Git att behandla alla sökvägsspecifikationer bokstavligt, snarare än som globmönster. Om du till exempel kör `GIT_LITERAL_PATHSPECS=1` `git` `log` `--` `*.c'` kommer det att söka efter commits som berör sökvägen `*.c`, inte några sökvägar som globen `*.c` matchar. Du kanske vill ha detta om du matar Git med bokstavliga sökvägar (t.ex. sökvägar som tidigare givits till dig av `git` `ls-tree`, `--raw` diff output, etc.).

[](https://git-scm.com/docs/git/sv#git-GITGLOBPATHSPECS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITGLOBPATHSPECScodespan)`GIT_GLOB_PATHSPECS`

Om denna booleska miljövariabel sätts till true kommer Git att behandla alla sökvägsspecs som glob-mönster (även känd som "glob"-magi).

[](https://git-scm.com/docs/git/sv#git-GITNOGLOBPATHSPECS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITNOGLOBPATHSPECScodespan)`GIT_NOGLOB_PATHSPECS`

Om denna booleska miljövariabel sätts till true kommer Git att behandla alla sökvägsspecs som literala (även känd som "literal" magi).

[](https://git-scm.com/docs/git/sv#git-GITICASEPATHSPECS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITICASEPATHSPECScodespan)`GIT_ICASE_PATHSPECS`

Om denna booleska miljövariabel sätts till sant kommer Git att behandla alla sökvägsspecifikationer som skiftläges-okänsliga.

[](https://git-scm.com/docs/git/sv#git-GITNOLAZYFETCH) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITNOLAZYFETCHcodespan)`GIT_NO_LAZY_FETCH`

Att sätta denna booleska miljövariabel till sant säger att Git inte ska lat-hämta saknade objekt från promisor-fjärr på begäran.

[](https://git-scm.com/docs/git/sv#git-GITREFLOGACTION) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITREFLOGACTIONcodespan)`GIT_REFLOG_ACTION`

När en referens uppdateras skapas reflogposter för att hålla reda på orsaken till att referensen uppdaterades (vilket vanligtvis är namnet på det högnivåkommando som uppdaterade referensen), utöver de gamla och nya värdena för referensen. Ett skriptat Porcelain-kommando kan använda hjälpfunktionen set_reflog_action i `git-sh-setup` för att sätta dess namn på denna variabel när den anropas som toppnivåkommando av slutanvändaren, för att registreras i refloggens brödtext.

[](https://git-scm.com/docs/git/sv#git-GITREFPARANOIA) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITREFPARANOIAcodespan)`GIT_REF_PARANOIA`

Om denna booleska miljövariabel är satt till falskt, ignorera trasiga eller felaktigt namngivna referenser när du itererar över listor med referenser. Normalt kommer Git att försöka inkludera sådana referenser, vilket kan orsaka att vissa operationer misslyckas. Detta är vanligtvis att föredra, eftersom potentiellt destruktiva operationer (t.ex. [git-prune[1]](https://git-scm.com/docs/git-prune/sv)) är bättre i att avbryta än att ignorera trasiga referenser (och därmed betrakta historiken de pekar på som inte värd att spara). Standardvärdet är `1` (dvs. var paranoid när det gäller att upptäcka och avbryta alla operationer). Du bör normalt inte behöva ställa in detta till `0`, men det kan vara användbart när du försöker rädda data från ett korrupt arkiv.

[](https://git-scm.com/docs/git/sv#git-GITCOMMITGRAPHPARANOIA) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITCOMMITGRAPHPARANOIAcodespan)`GIT_COMMIT_GRAPH_PARANOIA`

När ett incheckning-objekt laddas från inchecknings-graph utför Git en existenskontroll på objektet i objektdatabasen. Detta görs för att undvika problem med inaktuella inchecknings-grafer som innehåller referenser till redan borttagna incheckningar, men det kommer med en prestandaförsämring.
Standardvärdet är "false", vilket inaktiverar ovannämnda beteende. Om du ställer in detta på "true" aktiveras existenskontrollen så att inaktuella incheckninger aldrig returneras från inchecknings-grafen på bekostnad av prestanda.

[](https://git-scm.com/docs/git/sv#git-GITALLOWPROTOCOL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITALLOWPROTOCOLcodespan)`GIT_ALLOW_PROTOCOL`

Om den är inställd på en kolonseparerad lista med protokoll, beter sig som om `protocol.allow` är satt till `never`, och vart och ett av de listade protokollen har `protocol.`_< namn>_`.allow` satt till `always` (och åsidosätter eventuell befintlig konfiguration). Se beskrivningen av `protocol.allow` i [git-config[1]](https://git-scm.com/docs/git-config/sv) för mer information.

[](https://git-scm.com/docs/git/sv#git-GITPROTOCOLFROMUSER) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITPROTOCOLFROMUSERcodespan)`GIT_PROTOCOL_FROM_USER`

Sätt denna booleska miljövariabel till falskt för att förhindra att protokoll som används av fetch/push/clone och som är konfigurerade till tillståndet `user` används. Detta är användbart för att begränsa rekursiv undermodulinitiering från ett opålitligt arkiv eller för program som matar potentiellt opålitliga URL:er till git-kommandon. Se [git-config[1]](https://git-scm.com/docs/git-config/sv) för mer information.

[](https://git-scm.com/docs/git/sv#git-GITPROTOCOL) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITPROTOCOLcodespan)`GIT_PROTOCOL`

Endast för internt bruk. Används vid handskakning av länk-protokollet. Innehåller en lista med nycklar separerad med kolon _:_ och valfria värden _< nyckel>[=<värde>]_. Förekomst av okända nycklar och värden måste ignoreras.
Observera att servrar kan behöva konfigureras för att tillåta att denna variabel passerar över vissa transporter. Den kommer att spridas automatiskt vid åtkomst till lokala förvar (dvs. `file://` eller en filsystemssökväg), såväl som över `git://`-protokollet. För git-over-http bör det fungera automatiskt i de flesta konfigurationer, men se diskussionen i [git-http-backend[1]](https://git-scm.com/docs/git-http-backend/sv). För git-over-ssh kan ssh-servern behöva konfigureras för att tillåta klienter att skicka denna variabel (t.ex. genom att använda `AcceptEnv` `GIT_PROTOCOL` med OpenSSH).
This configuration is optional. If the variable is not propagated, then clients will fall back to the original "v0" protocol (but may miss out on some performance improvements or features). This variable currently only affects clones and fetches; it is not yet used for pushes (but may be in the future).

[](https://git-scm.com/docs/git/sv#git-GITOPTIONALLOCKS) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITOPTIONALLOCKScodespan)`GIT_OPTIONAL_LOCKS`

Om denna booleska miljövariabel är satt till falskt, kommer Git att slutföra alla begärda operationer utan att utföra några valfria deloperationer som kräver ett lås. Detta kommer till exempel att förhindra att `git` `status` uppdaterar indexet som en bieffekt. Detta är användbart för processer som körs i bakgrunden och som inte vill orsaka låskonflikter med andra operationer på arkivet. Standardvärdet är `1`.

[](https://git-scm.com/docs/git/sv#git-GITREDIRECTSTDIN) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITREDIRECTSTDINcodespan)`GIT_REDIRECT_STDIN`


[](https://git-scm.com/docs/git/sv#git-GITREDIRECTSTDOUT) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITREDIRECTSTDOUTcodespan)`GIT_REDIRECT_STDOUT`


[](https://git-scm.com/docs/git/sv#git-GITREDIRECTSTDERR) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITREDIRECTSTDERRcodespan)`GIT_REDIRECT_STDERR`

Endast Windows: tillåt omdirigering av standardreferenser för indata/utdata/fel till sökvägar som anges av miljövariablerna. Detta är särskilt användbart i flertrådade applikationer där det kanoniska sättet att skicka standardreferenser via `CreateProcess`() inte är ett alternativ eftersom det skulle kräva att referenserna markeras som ärvbara (och följaktligen skulle **varje** startad process ärva dem, vilket möjligen skulle blockera vanliga Git-operationer). Det primära avsedda användningsfallet är att använda namngivna pipes för kommunikation (t.ex. _\\\\.\pipe\my-git-stdin-123_).
Två specialvärden stöds: `off` stänger helt enkelt motsvarande standardreferens, och om `GIT_REDIRECT_STDERR` är _2 >&1_ kommer standardfelet att omdirigeras till samma referens som standardutdata.

[](https://git-scm.com/docs/git/sv#git-GITPRINTSHA1ELLIPSISfrldrad) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITPRINTSHA1ELLIPSIScodespanfrldrad)`GIT_PRINT_SHA1_ELLIPSIS` (föråldrad)

Om satt till `ja`, skriv ut en ellips efter ett (förkortat) SHA-1-värde. Detta påverkar indikationer på fristående HEADs ([git-checkout[1]](https://git-scm.com/docs/git-checkout/sv)) och den råa diff-utdatan ([git-diff[1]](https://git-scm.com/docs/git-diff/sv)). Att skriva ut en ellips i de nämnda fallen anses inte längre vara tillräckligt och stödet för den kommer sannolikt att tas bort inom överskådlig framtid (tillsammans med variabeln).

[](https://git-scm.com/docs/git/sv#git-GITADVICE) [](https://git-scm.com/docs/git/sv#git-spanclasssynopsiscodeGITADVICEcodespan)`GIT_ADVICE`

Om den är satt till `0`, inaktivera alla rådmeddelanden. Dessa meddelanden är avsedda att ge tips till mänskliga användare som kan hjälpa dem att ta sig ur problematiska situationer eller dra nytta av nya funktioner. Användare kan inaktivera enskilda meddelanden med hjälp av konfigurationsnycklarna `advice.*`. Dessa meddelanden kan störa verktyg som kör Git-processer, så den här variabeln är tillgänglig för att inaktivera meddelandena. (Det globala alternativet `--no-advice` är också tillgängligt, men gamla Git-versioner kan misslyckas när detta alternativ inte förstås. Miljövariabeln kommer att ignoreras av Git-versioner som inte förstår den.)
##  [](https://git-scm.com/docs/git/sv#_discussion)Discussion
More detail on the following is available from the [Git concepts chapter of the user-manual](https://git-scm.com/docs/user-manual/sv#git-concepts) and [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/sv).
A Git project normally consists of a working directory with a ".git" subdirectory at the top level. The .git directory contains, among other things, a compressed object database representing the complete history of the project, an "index" file which links that history to the current contents of the working tree, and named pointers into that history such as tags and branch heads.
Objektdatabasen innehåller objekt av tre huvudtyper: blobs, som innehåller fildata; träd, som pekar på blobs och andra träd för att bygga upp kataloghierarkier; och incheckningar, som var och en refererar till ett enda träd och ett antal förälder incheckningar.
En incheckning, motsvarande vad andra system kallar en "ändringsset" ("changeset") eller "version", representerar ett steg i projektets historik, och varje förälder representerar ett omedelbart föregående steg. Incheckning med mer än en förälder representerar sammanslagningar av oberoende utvecklingslinjer.
Alla objekt namnges med SHA-1-hashen för deras innehåll, normalt skriven som en sträng med 40 hexadecimalsiffror. Sådana namn är globalt unika. Hela historiken som leder fram till en incheckning kan bekräftas genom att signera just den incheckningen. En fjärde objekttyp, taggen, tillhandahålls för detta ändamål.
När objekt först skapas lagras de i individuella filer, men kan för effektivitets skull senare komprimeras till "paketfiler".
Namngivna pekare som kallas refs markerar intressanta punkter i historien. En ref kan innehålla SHA-1-namnet på ett objekt eller namnet på en annan ref (den senare kallas en "symbolisk ref"). Referenser med namn som börjar med `refs/head/` innehåller SHA-1-namnet på den senaste incheckning (eller "huvud") för en gren under utveckling. SHA-1-namn på taggar av intresse lagras under `refs/tags/`. En symbolisk ref med namnet `HEAD` innehåller namnet på den gren som för närvarande är utcheckad.
Indexfilen initieras med en lista över alla sökvägar och, för varje sökväg, ett blobobjekt och en uppsättning attribut. Blobobjektet representerar innehållet i filen från och med huvudet på den aktuella grenen. Attributen (senast ändrad tid, storlek, etc.) hämtas från motsvarande fil i arbetskatalog. Efterföljande ändringar i arbetskatalogen kan hittas genom att jämföra dessa attribut. Indexet kan uppdateras med nytt innehåll, och nya incheckningar kan skapas från innehållet som lagras i indexet.
Indexet kan också lagra flera poster (kallade "steg") för en given sökväg. Dessa steg används för att lagra de olika osammanslagna versionerna av en fil när en sammanslagning pågår.
##  [](https://git-scm.com/docs/git/sv#_s%C3%A4kerhet)SÄKERHET
Vissa konfigurationsalternativ och krok-filer kan få Git att köra godtyckliga shell-kommandon. Eftersom konfiguration och hooks inte kopieras med `git` `clone` är det generellt säkert att klona fjärrarkiv med otillförlitligt innehåll, inspektera dem med `git` `log` och så vidare.
Det är dock inte säkert att köra Git-kommandon i en `.git`-katalog (eller det arbetskatalog som omger den) när själva `.git`-katalogen kommer från en opålitlig källa. Kommandona i dess konfiguration och krokar exekveras på vanligt sätt.
Som standard, vägrar Git att köras när förvar ägs av någon annan än användaren som kör kommandot. Se posten för `safe.directory` i [git-config[1]](https://git-scm.com/docs/git-config/sv). Även om detta kan hjälpa till att skydda dig i en miljö med flera användare, observera att du också kan förvärva otillförlitliga förvar som ägs av dig (till exempel om du extraherar en zip-fil eller tarball från en otillförlitlig källa). I sådana fall måste du först "sanera" det otillförlitliga förvar.
Om du har en opålitlig `.git`-katalog bör du först klona den med `git` `clone` `--no-local` för att få en ren kopia. Git begränsar uppsättningen alternativ och krokar som kommer att köras av `upload-pack`, som hanterar serversidan av en klon eller hämtning, men var medveten om att ytan för attacker mot `upload-pack` är stor, så detta medför en viss risk. Det säkraste är att hantera förvaret som en oprivilegierad användare (antingen via [git-daemon[1]](https://git-scm.com/docs/git-daemon/sv), ssh eller med hjälp av andra verktyg för att ändra användar-ID). Se diskussionen i avsnittet _SÄKERHET_ i [git-upload-pack[1]](https://git-scm.com/docs/git-upload-pack/sv).
##  [](https://git-scm.com/docs/git/sv#_ytterligare_dokumentation)YTTERLIGARE DOKUMENTATION
Se referenserna i avsnittet "beskrivning" för att komma igång med Git. Följande är förmodligen mer detaljerat än nödvändigt för en förstagångsanvändare.
[kapitlet om Git-koncept i användarmanualen](https://git-scm.com/docs/user-manual/sv#git-concepts) och [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/sv) ger båda introduktioner till den underliggande Git-arkitekturen.
Se [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/sv) för en översikt över rekommenderade arbetsflöden.
Se även [howto](https://git-scm.com/docs/howto-index/sv)-dokumenten för några användbara exempel.
The internals are documented in the [Git API documentation](https://git-scm.com/docs/api-index/sv).
Användare som migrerar från CVS kan också vilja läsa [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/sv).
##  [](https://git-scm.com/docs/git/sv#_f%C3%B6rfattare)Författare
Git startades av Linus Torvalds och underhålls för närvarande av Junio C Hamano. Många bidrag har kommit från Git-e-postlistan <git@vger.kernel.org>. <https://openhub.net/p/git/contributors/summary> ger dig en mer komplett lista över bidragsgivare.
Om du har en klon av själva git.git, kan utdata från [git-shortlog[1]](https://git-scm.com/docs/git-shortlog/sv) och [git-blame[1]](https://git-scm.com/docs/git-blame/sv) visa dig författarna till specifika delar av projektet.
##  [](https://git-scm.com/docs/git/sv#_rapportera_buggar)Rapportera buggar
Rapportera buggar till Git-e-postlistan <git@vger.kernel.org> där utveckling och underhåll huvudsakligen sker. Du behöver inte prenumerera på listan för att skicka ett meddelande dit. Se listarkivet på <https://lore.kernel.org/git> för tidigare buggrapporter och andra diskussioner.
Säkerhetsrelevanta frågor bör delas privat till Git Securitys e-postlista <git-security@googlegroups.com>.
##  [](https://git-scm.com/docs/git/sv#_se_%C3%A4ven)SE ÄVEN
[gittutorial[7]](https://git-scm.com/docs/gittutorial/sv), [gittutorial-2[7]](https://git-scm.com/docs/gittutorial-2/sv), [giteveryday[7]](https://git-scm.com/docs/giteveryday/sv), [gitcvs-migration[7]](https://git-scm.com/docs/gitcvs-migration/sv), [gitglossary[7]](https://git-scm.com/docs/gitglossary/sv), [gitcore-tutorial[7]](https://git-scm.com/docs/gitcore-tutorial/sv), [gitcli[7]](https://git-scm.com/docs/gitcli/sv), [Git användarmanual](https://git-scm.com/docs/user-manual/sv), [gitworkflows[7]](https://git-scm.com/docs/gitworkflows/sv)
##  [](https://git-scm.com/docs/git/sv#_git)GIT
En del av [git[1]](https://git-scm.com/docs/git/sv)-sviten
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
